import {
  select,
  scaleLinear,
  scaleOrdinal,
  extent,
  axisBottom,
  axisLeft,
  csv,
  schemeSpectral
} from 'd3';


import { dropdownMenu } from './dropdownMenu.js';
import { loadAndProcessData } from './loadAndProcessData';
import { colorLegend } from './colorLegend';
import { scatterPlot } from './scatterPlot';


const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');

const scatterPlotG = svg.append('g');
const colorLegendG = svg.append('g')
    .attr('transform',`translate(860,80)`);


const colorScale = scaleOrdinal();
const colorValue = d => d.Year;


const title = 'London Monthly Air Quality: PM2.5 vs. PM10 Particulates';

const circleRadius = 10;
  
const margin = { top: 60, right: 130, bottom: 88, left: 150 };
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

let data;
let selectedColorValue;
let xColumn;
let yColumn;


const onClick = d => {
  selectedColorValue = d;
  render();
}

loadAndProcessData()
  .then(d => {
    data = d;
    xColumn = d.columns[4];
    yColumn = d.columns[7];
    render();
});

const onXColumnClicked = column => {
  xColumn = column;
  render();
};

const onYColumnClicked = column => {
  yColumn = column;
  render();
};

const render = () => {
  
  select('#x-menu')
    .call(dropdownMenu, {
      options: data.columns.filter(column =>
        column !== 'Date' &&
        column !== 'Year' &&
        column != 'Month' 
      ),
      onOptionClicked: onXColumnClicked,
      selectedOption: xColumn
    });

  select('#y-menu')
    .call(dropdownMenu, {
      options: data.columns.filter(column =>
        column !== 'Date' &&
        column !== 'Year' &&
        column != 'Month' 
      ),
      onOptionClicked: onYColumnClicked,
      selectedOption: yColumn
    });

  
  
  //colorScale function for years
  colorScale
    .domain(data.map(colorValue))
    .domain(colorScale.domain().sort().reverse())
    .range(schemeSpectral[colorScale.domain().length]); 

    scatterPlotG.call(scatterPlot,{
      data,
      colorValue,
      colorScale,
      selectedColorValue,
      width,
      height,
      margin,
      title: xColumn + ' vs ' + yColumn,
      xValue: d => d[xColumn],
      xAxisLabel: xColumn,
      yValue: d => d[yColumn],
      yAxisLabel: yColumn, 
      circleRadius,
      innerWidth,
      innerHeight
      });

  colorLegendG.call(colorLegend,{
    colorScale,
    circleRadius: 10,
    spacing: 25,
    textOffset: 16,
    backgroundRectWidth:92,
    onClick,
    selectedColorValue
  });
};